@@ -1,12 +1,10 @@
 import json
-import sys
 import os
-from aiconfig.callback import CallbackEvent, CallbackManager
-from .default_parsers.hf import HuggingFaceTextGenerationParser
-from .default_parsers.dalle import DalleImageGenerationParser
-import requests
+import sys
 from typing import ClassVar, Dict, List, Optional
 
+import requests
+from aiconfig.callback import CallbackEvent, CallbackManager
 from aiconfig.default_parsers.openai import (
     ChatGPTParser,
     DefaultOpenAIParser,
@@ -15,8 +13,14 @@ from aiconfig.default_parsers.openai import (
 )
 from aiconfig.default_parsers.palm import PaLMChatParser, PaLMTextParser
 from aiconfig.model_parser import InferenceOptions, ModelParser
+
+from .default_parsers.dalle import DalleImageGenerationParser
+from .default_parsers.hf import HuggingFaceTextGenerationParser
+from .registry import (
+    ModelParserRegistry,
+    update_model_parser_registry_with_config_runtime,
+)
 from .schema import AIConfig, ConfigMetadata, Prompt
-from .registry import ModelParserRegistry, update_model_parser_registry_with_config_runtime
 
 gpt_models = [
         "gpt-4",
