@@ -1,23 +1,27 @@
-from abc import abstractmethod
 import copy
+from abc import abstractmethod
 from typing import TYPE_CHECKING, Dict, List, Optional
 
-from ..model_parser import InferenceOptions
+import google.generativeai as palm
+from aiconfig.default_parsers.parameterized_model_parser import ParameterizedModelParser
+from aiconfig.util.config_utils import get_api_key_from_environment
+from aiconfig.util.params import (
+    resolve_parameters,
+    resolve_prompt,
+    resolve_system_prompt,
+)
+from google.generativeai.text import Completion
+
 from ..callback import CallbackEvent
+from ..model_parser import InferenceOptions
 from ..schema import (
     AIConfig,
     ExecuteResult,
-    ExecuteResult,
     ModelMetadata,
     Output,
     Prompt,
     PromptMetadata,
 )
-from aiconfig.default_parsers.parameterized_model_parser import ParameterizedModelParser
-from aiconfig.util.config_utils import get_api_key_from_environment
-from aiconfig.util.params import resolve_parameters, resolve_prompt, resolve_system_prompt
-import google.generativeai as palm
-from google.generativeai.text import Completion
 
 if TYPE_CHECKING:
     from aiconfig.Config import AIConfigRuntime
